install.packages("RColorBrewer")
install.packages("gplots")

source("http://bioconductor.org/biocLite.R")
biocLite()
biocLite("Rsubread")
biocLite("Rsamtools")
biocLite("edgeR")

library(Rsubread)

buildindex(basename="Genome_sequence_ToyExample_index", 
           reference="Genome_sequence_ToyExample.fa")
subjunc(index="Genome_sequence_ToyExample_index", 
        readfile1="Trimmed_reads_ToyExample_1.fq", readfile2="Trimmed_reads_ToyExample_2.fq", 
        input_format="FASTQ", output_format="BAM", output_file="Mapped_reads_ToyExample.BAM", 
        nthreads=1, phredOffset=64, unique=TRUE, minFragLength=50, maxFragLength=10000, 
        PE_orientation="fr")

library(Rsamtools, quietly=T)
sortBam(file="Mapped_reads_ToyExample.BAM", destination="Sorted_Mapped_reads_ToyExample")
indexBam("Sorted_Mapped_reads_ToyExample.bam")

Counts_ToyExample=featureCounts(files="Mapped_reads_ToyExample.BAM", 
                                annot.ext="Genome_annotation_ToyExample.gtf", 
                                isGTFAnnotationFile=T, GTF.featureType="exon", 
                                GTF.attrType="gene_id", useMetaFeatures=T, 
                                isPairedEnd=T, requireBothEndsMapped=T, 
                                checkFragLength=F, nthreads=1, strandSpecific=2, 
                                reportReads=T)
names(Counts_ToyExample)
head(Counts_ToyExample$counts)
Counts_ToyExample$stat
summary(Counts_ToyExample$counts)
hist(Counts_ToyExample$counts)
hist(log2(Counts_ToyExample$counts))
write.table(Counts_ToyExample$counts, "Counts_ToyExample.tsv", quote=F, sep="\t")
